import React from "react";
import { FaStar } from 'react-icons/fa';

type HeroAfricProps = {
  movie: any;
};

const HeroAfric: React.FC<HeroAfricProps> = ({ movie }) => {
  // Random rating between 4.2 and 9.8
  const randomRating = (Math.random() * (9.8 - 4.2) + 4.2).toFixed(1);

  const backgroundImage = `https://img.youtube.com/vi/${movie.id}/maxresdefault.jpg`; // YouTube thumbnail for background
  const title = movie.title;
  const country = movie.country;

  return (
    <div
      className="relative h-[60vh] md:h-[70vh] w-screen flex flex-col justify-end text-center bg-cover bg-center overflow-hidden"
      style={{ backgroundImage: `url(${backgroundImage})` }}
    >
      {/* Bottom fade overlay */}
      <div className="absolute inset-0 bg-gradient-to-t from-black to-transparent"></div>

      <div className="relative z-10 text-white mb-12 px-4 animate-fadeInUp">
        {/* Movie Title */}
        <h1 className="text-3xl lg:text-5xl font-bold mb-4 animate-slideInUp">
          {title}
        </h1>

        {/* Rating and Country */}
        <div className="flex justify-center items-center space-x-4 mb-2 animate-fadeIn">
          <div className="flex items-center">
            <FaStar className="h-5 w-5 text-yellow-400 mr-1" />
            <span>{randomRating}</span>
          </div>
          <span>•</span>
          <div className="flex items-center">
            <span>Country: {country}</span>
            <img
              src={`/flags/${country.toLowerCase()}.png`} // Fetching the flag image
              alt={country}
              className="ml-2 h-5 w-8"
            />
          </div>
        </div>
      </div>

      <style jsx>{`
        @keyframes fadeInUp {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes slideInUp {
          from {
            opacity: 0;
            transform: translateY(50px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes fadeIn {
          from {
            opacity: 0;
          }
          to {
            opacity: 1;
          }
        }

        .animate-fadeInUp {
          animation: fadeInUp 1s ease-out forwards;
        }

        .animate-slideInUp {
          animation: slideInUp 1s ease-out forwards;
        }

        .animate-fadeIn {
          animation: fadeIn 1s ease-out forwards;
        }
      `}</style>
    </div>
  );
};

export default HeroAfric;
